==> dl.php?src=linea21_1_3.zip: linea21/languages/it/lang_home.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['home']['name']="Home";
$lang['home']['project']="Progetti in scadenza";
$lang['home']['yp']="organizzazione(i) attualmente in pre-iscrizione";
$lang['home']['dashboard']="indicatore(i) da aggiornare";
$lang['home']['user']="utente(i) iscritto(i) dall'ultima connessione";
$lang['home']['news']="Ultime 3 news";
$lang['home']['publi']="ultime cartelle pubblicate";
$lang['home']['report']="ultimo rapporto pubblicato";
$lang['home']['accueil']="Benvenuti nell'interfaccia di amministrazione Linea 21, ogni modulo è accessibile a seconda dei diritti fissati dall'amministratore. Per qualsiasi domanda o osservazione sulla gestione dei moduli d'amministrazione, potete contattare direttamente il supporto online a questo indirizzo ";

$lang['home']['resume']="Mansioni di amministrazione Linea 21";
$lang['home']['noresult']="Attualmente nessun dato è stato pubblicato per questo modulo";
$lang['home']['noupdate']="Attualmente nessun dato dev'essere aggiornato per questo modulo";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Per accedere a un modulo di gestione, clicca sul suo nome nel menù a sinistra dell'applicazione";
$lang['home']['help_list2']="Puoi realizzare una ricerca globale in ogni momento utilizzando il campo di inserimento \"ricerca\"";
$lang['home']['help_list3']="Per effettuare una ricerca per modulo, clicca su ricerca nella barra dgli strumenti";
$lang['home']['help_list4']="la guida in linea contiene indicazioni per la gestione di ogni modulo, non esitare a consultarla !";


?>

==> dl.php?src=linea21_1_6.zip: linea21/languages/it/lang_home.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['home']['name']="Home";
$lang['home']['comment']="Latest %s comments"; // @todo translation
$lang['home']['comment_to_moderate']="%s comments to moderate"; // @todo translation
$lang['home']['project']="Progetti in scadenza";
$lang['home']['workshop_pending_users']="workgroups : %s pending users"; // @todo translation
$lang['home']['yp']="organizzazione(i) attualmente in pre-iscrizione";
$lang['home']['dashboard']="indicatore(i) da aggiornare";
$lang['home']['user']="utente(i) iscritto(i) dall'ultima connessione";
$lang['home']['news']="Ultime 3 news";
$lang['home']['publi']="ultime cartelle pubblicate";
$lang['home']['report']="ultimo rapporto pubblicato";
$lang['home']['accueil']="Benvenuti nell'interfaccia di amministrazione Linea 21, ogni modulo è accessibile a seconda dei diritti fissati dall'amministratore. Per qualsiasi domanda o osservazione sulla gestione dei moduli d'amministrazione, potete contattare direttamente il supporto online a questo indirizzo ";

$lang['home']['resume']="Mansioni di amministrazione Linea 21";
$lang['home']['noresult']="Attualmente nessun dato è stato pubblicato per questo modulo";
$lang['home']['noupdate']="Attualmente nessun dato dev'essere aggiornato per questo modulo";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Per accedere a un modulo di gestione, clicca sul suo nome nel menù a sinistra dell'applicazione";
$lang['home']['help_list2']="Puoi realizzare una ricerca globale in ogni momento utilizzando il campo di inserimento \"ricerca\"";
$lang['home']['help_list3']="Per effettuare una ricerca per modulo, clicca su ricerca nella barra dgli strumenti";
$lang['home']['help_list4']="la guida in linea contiene indicazioni per la gestione di ogni modulo, non esitare a consultarla !";


?>
